==> cudaBayesreg_0.1-1.tar.gz: cudaBayesreg/R/post.ppm.R <==

post.ppm <-
function(out, slicedata, vreg = 2, swap = F, plot = T)
{
    # Mask out slice times series
    ymask <- premask(slicedata)
    kin <- ymask$kin
    #-----------
    niislicets <- slicedata$niislicets
    niislicets <- niislicets[,,1] # ! radiological convention 
		if(swap)
	      niislicets <- niislicets[dm[1]:1,,1] # ! radiological convention 
    mask <- slicedata$mask
    dm <- dim(mask)
    # cat("mask ",dm,"\n")
    if(plot) { # initial pre-filtered image
        x11(width=4,height=4.5)
        par(mar=c(0,0,2,0), xaxt="n", yaxt="n", ask=F)
        image(niislicets, col=heat.colors(256), main="initial pre-filtered image",
                  axes=F)
        # image(niislicets[,,1], col=gray((0:255)/256))
		}
    #-------------------
    pmeans = pmeans.hcoef(out$betadraw) 
    px <- regpostsim(pmeans, vreg=vreg, plot=F)
    pm2 <- pmeans[,vreg]
    spma <- px$spma
    spmn <- px$spmn
		nactive	<- length(spma)
    #---------
#    # mean activation image
#    print("mean activation:")
#    spm <- matrix(0, nrow=dm[1], ncol=dm[2])
#    print(dim(spm))
#    spm[kin] <- pm2
#    if(swap)
#        spm <- spm[dm[1]:1, ] # ! radiological convention 
#    if(plot) {
#        x11(width=4,height=4.5)
#        par(mar=c(0,0,2,0), xaxt="n", yaxt="n", ask=F)
#        image(spm, col=heat.colors(256), main="mean activation", axes=F)
#    }
    #-----------
    # ppm image 
    pm2.act <- pm2[spma]
    ppm <- matrix(0, nrow=dm[1], ncol=dm[2])
    if(length(pm2.act))
        ppm[kin[spma,]] <- pm2.act
    # plot with overlay
    # ppm.m <- ppm+0.3*mask
    ppm.m <- ppm/max(ppm) * 0.65 + niislicets/max(niislicets) * 0.35
    ppm.m <- ppm.m/max(ppm.m) * mask
    if(swap) 
        ppm.m <- ppm.m[dm[1]:1, ] # ! radiological convention 
    if(plot) {
        x11(width=4,height=4.5)
        par(mar=c(0,0,2,0), xaxt="n", yaxt="n", ask=F)
    		main <- paste("ppm image ; vreg = ",vreg,sep="") 
        image(ppm.m, col=heat.colors(256), main=main, axes=F)
        # image(ppm.m, col=gray((0:255)/256), main="ppm image", axes=F)
    }
		invisible(list(ppm=ppm, nactive=nactive))
}

==> cudaBayesreg_0.2-1.tar.gz: cudaBayesreg/R/post.ppm.R <==

post.ppm <-
function(out, slicedata, vreg = 2, swap = F, plot = T)
{
    x11(width=4,height=4.5)
    op <- par(no.readonly = TRUE)
    on.exit(par(op))
    # Mask out slice times series
    ymask <- premask(slicedata)
    kin <- ymask$kin
    #-----------
    niislicets <- slicedata$niislicets
    niislicets <- niislicets[,,1] # ! radiological convention 
		if(swap)
	      niislicets <- niislicets[dm[1]:1,,1] # ! radiological convention 
    mask <- slicedata$mask
    dm <- dim(mask)
    # cat("mask ",dm,"\n")
    if(plot) { # initial pre-filtered image
        #x11(width=4,height=4.5)
        par(mar=c(0,0,2,0), xaxt="n", yaxt="n", ask=T)
        image(niislicets, col=heat.colors(256), main="initial pre-filtered image",
                  axes=F)
        # image(niislicets[,,1], col=gray((0:255)/256))
		}
    #-------------------
    pmeans = pmeans.hcoef(out$betadraw) 
    px <- regpostsim(pmeans, vreg=vreg, plot=F)
    pm2 <- pmeans[,vreg]
    spma <- px$spma
    spmn <- px$spmn
		nactive	<- length(spma)
    #---------
#    # mean activation image
#    print("mean activation:")
#    spm <- matrix(0, nrow=dm[1], ncol=dm[2])
#    print(dim(spm))
#    spm[kin] <- pm2
#    if(swap)
#        spm <- spm[dm[1]:1, ] # ! radiological convention 
#    if(plot) {
#        x11(width=4,height=4.5)
#        par(mar=c(0,0,2,0), xaxt="n", yaxt="n", ask=F)
#        image(spm, col=heat.colors(256), main="mean activation", axes=F)
#    }
    #-----------
    # ppm image 
    pm2.act <- pm2[spma]
    ppm <- matrix(0, nrow=dm[1], ncol=dm[2])
    if(length(pm2.act))
        ppm[kin[spma,]] <- pm2.act
    # plot with overlay
    # ppm.m <- ppm+0.3*mask
    ppm.m <- ppm/max(ppm) * 0.65 + niislicets/max(niislicets) * 0.35
    ppm.m <- ppm.m/max(ppm.m) * mask
    if(swap) 
        ppm.m <- ppm.m[dm[1]:1, ] # ! radiological convention 
    if(plot) {
        # x11(width=4,height=4.5)
        par(mar=c(0,0,2,0), xaxt="n", yaxt="n", ask=T)
    		main <- paste("ppm image ; vreg = ",vreg,sep="") 
        image(ppm.m, col=heat.colors(256), main=main, axes=F)
        # image(ppm.m, col=gray((0:255)/256), main="ppm image", axes=F)
    }
		invisible(list(ppm=ppm, nactive=nactive))
}
